@@ -441,10 +441,10 @@ def _rename_notebook(config, old_path, new_path):
         for (key, _) in (yield _list_all_successor_keys(config, old_key + '/'))
     ]
 
-    for (old_key, new_key) in object_key + sorted(renames, key=lambda k: _get_copy_key(k[0])):
+    for (old_key, new_key) in object_key + sorted(renames, key=lambda k: _get_copy_order_key(k[0])):
         yield _copy_key_object(config, old_key, new_key)
 
-    for (old_key, _) in sorted(renames, key=lambda k: _delete_copy_key(k[0])) + object_key:
+    for (old_key, _) in sorted(renames, key=lambda k: _delete_order_key(k[0])) + object_key:
         yield _delete_key_object(config, old_key)
 
     return (yield _get_model(config, new_path, content=False, type=None, format=None))
@@ -520,7 +520,7 @@ def _delete_notebook(config, path):
         for (key, _) in (yield _list_all_successor_keys(config, root_key + '/'))
     ]
 
-    for key in sorted(descendant_keys, key=_delete_copy_key) + object_key:
+    for key in sorted(descendant_keys, key=_delete_order_key) + object_key:
         yield _delete_key_object(config, key)
 
 
@@ -532,7 +532,7 @@ def _get_checkpoint_model(config, type, checkpoint_id, path):
 
 
 @gen.coroutine
-def _delete__notebook_checkpoint(config, checkpoint_id, path):
+def _delete_notebook_checkpoint(config, checkpoint_id, path):
     checkpoint_path = _get_checkpoint_path(path, checkpoint_id)
     yield _delete_notebook(config, checkpoint_path)
 
@@ -672,10 +672,10 @@ def _copy_key_object(config, old_key, new_key):
     yield _copy_object(config, config.bucket_name, old_key, new_key)
 
 
-def _get_copy_key(key):
+def _get_copy_order_key(key):
     return (key.count('/'), 0 if key.endswith(FOLDER_SEPERATOR) else 1)
 
-def _delete_copy_key(key):
-    return tuple(-1 * key_i for key_i in _copy_sort_key(key))
+def _delete_order_key(key):
+    return tuple(-1 * key_i for key_i in _get_copy_order_key(key))
 
 
